package
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: Jan 11, 2019
License: NCSA
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type APNSAlert struct {
Title string `json:"title"`
Body string `json:"body"`
}
type APNSPayload struct {
Alert APNSAlert `json:"alert"`
}
type Device struct {
UserID string `json:"userId"`
DeviceToken string `json:"deviceToken"`
DeviceArn string `json:"deviceArn"`
Platform string `json:"platform"`
Subscriptions map[string]string `json:"subscriptions"`
}
type DeviceRegistration struct {
DeviceToken string `json:"deviceToken"`
Platform string `json:"platform"`
}
type GCMNotification struct {
Title string `json:"title"`
Body string `json:"body"`
}
type GCMPayload struct {
Notification GCMNotification `json:"notification"`
}
type Notification struct {
Body string `json:"body"`
Title string `json:"title"`
}
type NotificationList struct {
Notifications []PastNotification `json:"notifications"`
}
type NotificationPayload struct {
APNS string `json:"APNS"`
GCM string `json:"GCM"`
Default string `json:"default"`
}
type PastNotification struct {
TopicName string `json:"topicName"`
Body string `json:"body"`
Title string `json:"title"`
Time int64 `json:"time"`
}
type Topic struct {
Name string `json:"name"`
Arn string `json:"arn"`
UserIDs []string `json:"userIds"`
}
type TopicList struct {
Topics []string `json:"topics"`
}
type TopicName struct {
Name string `json:"name"`
}
type TopicPublic struct {
Name string `json:"name"`
UserIDs []string `json:"userIds"`
}
type UserIDList struct {
UserIDs []string `json:"userIds"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.